(_api_observation)=
# Observation

## Base Class
```{eval-rst}
.. autosummary::
    :toctree: generated/

    skretrieval.retrieval.observation.Observation

```

## Simulated Observations
```{eval-rst}
.. autosummary::
    :toctree: generated/

    skretrieval.retrieval.observation.SimulatedLimbObservation
    skretrieval.retrieval.observation.SimulatedNadirObservation

```
